@@ -1,4 +1,6 @@
-#' Title
+#' standardBootIntervals
+#'
+#' This returns the quantiles of the bootstrap samples specified by the user. The quantiles uses the type=6 argument of the quantile function, which appears to function best.
 #'
 #' @param boot A vector of bootstrap results
 #' @param lower the lower alpha
@@ -13,7 +15,7 @@
 #' apply(boots,1, standardBootIntervals)
 #' DFanalysis(data,1,2,3)
 standardBootIntervals<-function(boot, lower=.025, upper=.975){
-  Intervals<-matrix(c(mean(boot), median(boot), min(boot), max(boot), quantile(boot,c(lower,upper))),nrow=1)
+  Intervals<-matrix(c(mean(boot), median(boot), min(boot), max(boot), quantile(boot,c(lower,upper),type=6)),nrow=1)
   colnames(Intervals)<-c("mean", "median", "min", "max", paste("standard", lower, "CI"), paste("standard", upper, "CI"))
   return(Intervals)
-}
\ No newline at end of file
+}
